from django.shortcuts import render
from django.contrib.auth.models import User
from django.contrib.auth.decorators import login_required
from guestbook.models import Message
from django.http import HttpResponseRedirect
from django.urls import reverse

from django import forms

from guestbook.avatar_management import upload_avatar

class MessageForm(forms.Form):
    subj = forms.CharField(required=False)
    text = forms.CharField(widget=forms.Textarea)


class ProfileForm(forms.Form):
    userpic = forms.ImageField(required=False)

# Create your views here.

def main_view(request):
    messages = Message.objects.order_by("-pub_date")
    context = {"messages": messages}
    return render(request, "main.html", context)


def add_view(request):
    if request.method == "POST":
        form = MessageForm(request.POST)
        if form.is_valid():
            msg_subj = form.cleaned_data["subj"]
            msg_text = form.cleaned_data["text"]
            msg_author = None
            if request.user.is_authenticated:
                msg_author = request.user
            new_msg = Message(author=msg_author, subj=msg_subj, text=msg_text)
            new_msg.save()

            return HttpResponseRedirect(reverse("main"))
    else:
        form = MessageForm()

    return render(request, "add_form.html", {"form": form})


@login_required
def profile_view(request):
    errors = []
    profile = request.user.userprofile
    if request.method == "POST":
        form = ProfileForm(request.POST, request.FILES)
        if form.is_valid():
            try:
                image_file = request.FILES["userpic"]
            except KeyError:
                image_file = None
            if image_file is not None:
                if image_file.size < 20 * 1024 * 1024:
                    try:
                        processed_file = upload_avatar(image_file)
                    except Exception as e:
                        processed_file = None
                        errors.append(" ".join(e.args))
                    profile.userpic.save(image_file.name, processed_file, save=True)
                    return HttpResponseRedirect(reverse("main"))
    else:
        form = ProfileForm()

    return render(request, "profile_form.html", {"form": form, "profile": profile, "errors": errors})
