from django.contrib.auth.forms import UserCreationForm, UsernameField
from django.contrib.auth import login
from django.contrib.auth.models import User
from django.http import HttpResponseRedirect
from django.shortcuts import render
from django import forms

from guestbook.models import UserProfile

class RegistrationForm(UserCreationForm):
    class Meta:
        model = User
        fields = ("username", "email")
        field_classes = {"username": UsernameField}

def register_new_user(request):
    if request.user.is_authenticated:
        return HttpResponseRedirect("/")

    if request.method == "POST":
        form = RegistrationForm(request.POST)
        if form.is_valid():
            user = form.save()
            profile = UserProfile(user=user)
            profile.save()
            login(request, user)
            return render(request, "registration/user_register_done.html")
    else:
        form = RegistrationForm()

    return render(request, "registration/user_register_form.html", context={"form": form})
